@@ -16,7 +16,7 @@ sub process {
       $attrs->{minified} = 1;
       return if $asset->format ne 'css' or $asset->minified;
       return $asset->content($file)->minified(1) if $file = $store->load($attrs);
-      load_module 'CSS::Minifier::XS' or die qq(Could not load "CSS::Minifier::XS": $@);
+      load_module 'CSS::Minifier::XS';
       diag 'Minify "%s" with checksum %s.', $asset->url, $asset->checksum if DEBUG;
       my $css = CSS::Minifier::XS::minify($asset->content);
       $asset->content($store->save(\$css, $attrs))->minified(1);
