@@ -1,7 +1,6 @@
 package Mojolicious::Plugin::AssetPack::Pipe::Less;
 use Mojo::Base 'Mojolicious::Plugin::AssetPack::Pipe';
 use Mojolicious::Plugin::AssetPack::Util qw(diag $CWD DEBUG);
-use File::Basename 'dirname';
 
 sub process {
   my ($self, $assets) = @_;
@@ -19,7 +18,7 @@ sub process {
       my @args = qw(lessc --no-color);
       my $file
         = $asset->path ? $asset : Mojo::Asset::File->new->add_chunk($asset->content);
-      push @args, '--include-path='.dirname($asset->path) if $asset->path;
+      push @args, '--include-path=' . $asset->path->dirname if $asset->path;
       push @args, $file->path;
       $self->run(\@args, undef, \my $css);
       $asset->content($store->save(\$css, $attrs))->FROM_JSON($attrs);
